@@ -425,7 +425,7 @@ def swok():
 
 onlyone()
 logno=1
-swdb=c_oracle(yslj=True,raiseExp=True)
+swdb=c_oracle()
 swid=swenv("swid",0)
 logid=swenv("logid",0)
 loglevel=swenv("loglevel",5)
