@@ -54,6 +54,11 @@ class c_database(object):
             return jg[0]
         else:
             return jg
+    def xg(self,ssql,*args,**kwargs):
+        '''主要用于修改，执行完后附加commit操作'''
+        c=self.execute(ssql,*args,**kwargs)
+        self.commit()
+        return c
     def __getattribute__(self,name):
         if name in ("c","conn") and not self.connected:
             self.connected=True
