@@ -45,10 +45,10 @@ class c_xxtz(object):
 class c_xx(object):   #消息处理
     def __init__(self):
         self.cc=sw3.c_oracle("sw3msg@cc",yslj=True)
-    def dwx(self,组,消息内容,标题=None,消息保存天数=30):
+    def dwx(self,组,消息内容,标题=None,消息保存天数=30,栏目=''):
         for 组id in self.组解析(组):
             self.dx(组id,消息内容,标题,消息保存天数)
-            self.wx(组id,消息内容,标题,消息保存天数)
+            self.wx(组id,消息内容,标题,消息保存天数,栏目)
     def dx(self,组,消息内容,标题=None,消息保存天数=30):
         s=sys._getframe(1)
         标题=标题 or "%s:%d" %(s.f_code.co_filename.split("/")[-1] , s.f_lineno)
@@ -60,11 +60,11 @@ class c_xx(object):   #消息处理
         if 消息内容=="":消息内容="正常"
         for 组id in self.组解析(组):
             self.cc.execute("select f_gzt(:z,:xxnr,:bt,:ts) from dual",z=组id,xxnr="%s|1|%s" %(消息标识,消息内容),bt=标题,ts=消息保存天数)
-    def wx(self,组,消息内容,标题=None,消息保存天数=30):
+    def wx(self,组,消息内容,标题=None,消息保存天数=30,栏目=''):
         s=sys._getframe(1)
         标题=标题 or "%s:%d" %(s.f_code.co_filename.split("/")[-1] , s.f_lineno)
         for 组id in self.组解析(组):
-            self.cc.execute("select f_wx(:z,:xxnr,:bt,:ts) from dual",z=组id,xxnr=消息内容,bt=标题,ts=消息保存天数)
+            self.cc.execute("select f_wx(:z,:xxnr,:bt,:ts,:lm) from dual",z=组id,xxnr=消息内容,bt=标题,ts=消息保存天数,lm=栏目)
     def mail(self,组,消息内容,标题=None,消息保存天数=30):
         s=sys._getframe(1)
         标题=标题 or "%s:%d" %(s.f_code.co_filename.split("/")[-1] , s.f_lineno)
